Exception: Kobako::Codec::InvalidType
- Defined in:
- lib/kobako/codec/error.rb,
sig/kobako/codec/error.rbs
Overview
The type byte at the current position is not in the 12-entry kobako type mapping (e.g. an unknown ext code, or a reserved msgpack tag).
The type byte at the current position is not in the 12-entry kobako type mapping (e.g. an unknown ext code, or a reserved msgpack tag).