Exception: Kobako::Wire::Codec::InvalidType
- Defined in:
- lib/kobako/wire/codec/error.rb
Overview
The type byte at the current position is not in the 12-entry kobako type mapping (e.g. an unknown ext code, or a reserved msgpack tag).
The type byte at the current position is not in the 12-entry kobako type mapping (e.g. an unknown ext code, or a reserved msgpack tag).