Exception: Kobako::SandboxError
- Defined in:
- lib/kobako/errors.rb
Overview
Sandbox / wire layer. Raised when the guest ran to completion but execution failed due to a mruby script error, a protocol fault, or a host-side wire decode failure on an otherwise valid outcome tag.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#backtrace_lines ⇒ Object
readonly
Returns the value of attribute backtrace_lines.
-
#details ⇒ Object
readonly
Returns the value of attribute details.
-
#klass ⇒ Object
readonly
Returns the value of attribute klass.
-
#origin ⇒ Object
readonly
Returns the value of attribute origin.
Instance Method Summary collapse
-
#initialize(message, origin: nil, klass: nil, backtrace_lines: nil, details: nil) ⇒ SandboxError
constructor
A new instance of SandboxError.
Constructor Details
#initialize(message, origin: nil, klass: nil, backtrace_lines: nil, details: nil) ⇒ SandboxError
Returns a new instance of SandboxError.
99 100 101 102 103 104 105 |
# File 'lib/kobako/errors.rb', line 99 def initialize(, origin: nil, klass: nil, backtrace_lines: nil, details: nil) super() @origin = origin @klass = klass @backtrace_lines = backtrace_lines @details = details end |
Instance Attribute Details
#backtrace_lines ⇒ Object (readonly)
Returns the value of attribute backtrace_lines.
97 98 99 |
# File 'lib/kobako/errors.rb', line 97 def backtrace_lines @backtrace_lines end |
#details ⇒ Object (readonly)
Returns the value of attribute details.
97 98 99 |
# File 'lib/kobako/errors.rb', line 97 def details @details end |
#klass ⇒ Object (readonly)
Returns the value of attribute klass.
97 98 99 |
# File 'lib/kobako/errors.rb', line 97 def klass @klass end |
#origin ⇒ Object (readonly)
Returns the value of attribute origin.
97 98 99 |
# File 'lib/kobako/errors.rb', line 97 def origin @origin end |