Exception: Kobako::SandboxError
- Defined in:
- lib/kobako/errors.rb
Overview
Sandbox / wire layer. Raised when the guest ran to completion but execution failed due to a mruby script error, a protocol fault, or a host-side wire decode failure on an otherwise valid outcome tag.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#backtrace_lines ⇒ Object
readonly
Returns the value of attribute backtrace_lines.
-
#details ⇒ Object
readonly
Returns the value of attribute details.
-
#klass ⇒ Object
readonly
Returns the value of attribute klass.
-
#origin ⇒ Object
readonly
Returns the value of attribute origin.
Instance Method Summary collapse
-
#initialize(message, origin: nil, klass: nil, backtrace_lines: nil, details: nil) ⇒ SandboxError
constructor
A new instance of SandboxError.
Constructor Details
#initialize(message, origin: nil, klass: nil, backtrace_lines: nil, details: nil) ⇒ SandboxError
Returns a new instance of SandboxError.
45 46 47 48 49 50 51 |
# File 'lib/kobako/errors.rb', line 45 def initialize(, origin: nil, klass: nil, backtrace_lines: nil, details: nil) super() @origin = origin @klass = klass @backtrace_lines = backtrace_lines @details = details end |
Instance Attribute Details
#backtrace_lines ⇒ Object (readonly)
Returns the value of attribute backtrace_lines.
43 44 45 |
# File 'lib/kobako/errors.rb', line 43 def backtrace_lines @backtrace_lines end |
#details ⇒ Object (readonly)
Returns the value of attribute details.
43 44 45 |
# File 'lib/kobako/errors.rb', line 43 def details @details end |
#klass ⇒ Object (readonly)
Returns the value of attribute klass.
43 44 45 |
# File 'lib/kobako/errors.rb', line 43 def klass @klass end |
#origin ⇒ Object (readonly)
Returns the value of attribute origin.
43 44 45 |
# File 'lib/kobako/errors.rb', line 43 def origin @origin end |